@@ -259,7 +259,7 @@ class StreamingWsgiChannel(WsgiChannel):
 
     def stopStream(self, msg):
         """Stop a streaming connection."""
-        connection = self.channel_set.getConnection(msg.headers.get(msg.FLEX_CLIENT_ID_HEADER))
+        connection = self.channel_set.connection_manager.getConnection(msg.headers.get(msg.FLEX_CLIENT_ID_HEADER))
         connection.disconnect()
         if hasattr(connection, "notify_func") and connection.notify_func is not None:
             connection.notify_func()
